/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.security;

import java.util.*;

public final class Role implements Comparable, Cloneable
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int level;                // access level in this role
  private String name;              // human-readable name
  private String symbol;            // programmatic symbol

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  protected Role(int level, String name)
  {
    this.level = level;
    this.name = name;
    this.symbol = null;

  } // end constructor

  protected Role(int level, String name, String symbol)
  {
    this.level = level;
    this.name = name;
    this.symbol = symbol;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class Object
   *--------------------------------------------------------------------------------
   */

  public boolean equals(Object obj)
  {
    if (obj==null)
      return false;
    else if (obj==this)
      return true;
    if (obj instanceof Role)
    { // compare levels
      Role other = (Role)obj;
      return (level==other.level);

    } // end if

    return obj.toString().equals(toString());

  } // end equals

  public int hashCode()
  {
    return level;

  } // end hashCode

  public String toString()
  {
    StringBuffer buf = new StringBuffer(name);
    buf.append('[').append(level).append(']');
    if (symbol!=null)
      buf.append('{').append(symbol).append('}');
    return buf.toString();

  } // end toString

  /*--------------------------------------------------------------------------------
   * Implementations from interface Comparable
   *--------------------------------------------------------------------------------
   */

  public int compareTo(Object obj)
  {
    if (obj==null)
      throw new NullPointerException("comparing a NULL object");
    if (!(obj instanceof Role))
      throw new ClassCastException("comparing non-Role to Role");
    Role other = (Role)obj;
    return level - other.level;

  } // end compareTo

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final int getLevel()
  {
    return level;

  } // end getLevel

  public final String getName()
  {
    return name;

  } // end getName

  public final String getSymbol()
  {
    return symbol;

  } // end getSymbol

  public final boolean isSatisfiedBy(int l)
  {
    return (l>=level);

  } // end isSatisfiedBy

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static final Role create(int level, String name, String symbol)
  {
    return new Role(level,name,symbol);

  } // end create

} // end class Role
